@@ -109,7 +109,7 @@ var _ = Describe("Generating fluentd config", func() {
                 retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                 overflow_action block
               </buffer>
@@ -152,7 +152,7 @@ var _ = Describe("Generating fluentd config", func() {
                 retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                 overflow_action block
               </buffer>
@@ -235,7 +235,7 @@ var _ = Describe("Generating fluentd config", func() {
                 retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                 overflow_action block
               </buffer>
@@ -278,7 +278,7 @@ var _ = Describe("Generating fluentd config", func() {
                 retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                 overflow_action block
               </buffer>
@@ -432,7 +432,7 @@ var _ = Describe("Generating fluentd config", func() {
             @type file
             path '/var/lib/fluentd/secureforward_receiver'
             queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
-            total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+            total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
             chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
             flush_mode interval
             flush_interval 5s
@@ -560,7 +560,7 @@ var _ = Describe("Generating fluentd config", func() {
                 retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                 chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                 overflow_action block
               </buffer>
@@ -667,7 +667,7 @@ var _ = Describe("Generating fluentd config", func() {
                retry_max_interval 60s
                retry_forever true
                queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-               total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+               total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
                chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
                overflow_action block
            </buffer>
